==> haskell-microlens-platform-0.4.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.4.0
id: microlens-platform-0.4.0-37EpiMtV3nA5oty7dCOHgK
key: microlens-platform-0.4.0-37EpiMtV3nA5oty7dCOHgK
license: BSD-3-Clause
maintainer: Monadfix <hi@monadfix.io>
author: Edward Kmett, Artyom Kazak
homepage: http://github.com/monadfix/microlens
synopsis: microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.
category: Data, Lenses
abi: 439ea6154644ceae91c08ea4b8b1a4ec
exposed: True
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-platform-0.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-platform-0.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-platform-0.4.0
hs-libraries: HSmicrolens-platform-0.4.0-37EpiMtV3nA5oty7dCOHgK
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR
    microlens-ghc-0.4.11.1-8gcYrT9eyRBCx0ooiq6T3c
    microlens-mtl-0.2.0.1-YTFbHudevv9mEzCYQBIKT
    microlens-th-0.4.3.2-BtNcM50Dy9m529DwUGkRbV text-1.2.3.1
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-platform-0.4.0-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.4.0
id: microlens-platform-0.4.0-1jgy58AvuPAHM7vkk3NAjq
key: microlens-platform-0.4.0-1jgy58AvuPAHM7vkk3NAjq
license: BSD-3-Clause
maintainer: Monadfix <hi@monadfix.io>
author: Edward Kmett, Artyom Kazak
homepage: http://github.com/monadfix/microlens
synopsis: microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.
category: Data, Lenses
abi: fafa3c8074f83819fd9a35e1d8c22db6
exposed: True
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-platform-0.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-platform-0.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-platform-0.4.0
hs-libraries: HSmicrolens-platform-0.4.0-1jgy58AvuPAHM7vkk3NAjq
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR
    microlens-ghc-0.4.11.1-8gcYrT9eyRBCx0ooiq6T3c
    microlens-mtl-0.2.0.1-YTFbHudevv9mEzCYQBIKT
    microlens-th-0.4.3.2-BtNcM50Dy9m529DwUGkRbV text-1.2.3.1
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
